#!../venv/bin/python3.7

# Script used to convert .ui files made by Qt5 Designer into pyqt Python files.

import os


def create_window_file(base_name: str, dest_dir: str):
    camel_basename = base_name.replace("_", " ").title().replace(" ", "")
    content = "from PyQt5.QtWidgets import QDialog\n"
    content += (
        "from " + "gui.ui_" + base_name.lower() + " import Ui_" + camel_basename + "\n"
    )
    content += "\n"
    content += "\n"
    content += "class " + camel_basename + "(QDialog):\n"
    content += "    def __init__(self, parent_window):\n"
    content += "        super(" + camel_basename + ", self).__init__(parent_window)\n"
    content += "        self.ui = Ui_" + camel_basename + "()\n"
    content += "        self.ui.setupUi(self)\n"

    dest_filename = os.path.join(dest_dir, base_name + ".py")
    with open(dest_filename, "w") as out_file:
        out_file.write(content)


# Determine the projects base path and the directory containing the .ui files.
possible_base_paths = ["../", "../../"]
pyqt_dir = None
base_path = None
for possible_base_path in possible_base_paths:
    possible_pyqt_dir = os.path.join(possible_base_path, "pyqt")
    if os.path.exists(possible_pyqt_dir):
        pyqt_dir = possible_pyqt_dir
        base_path = possible_base_path
if pyqt_dir is None:
    raise FileNotFoundError("Could not find the directory containing the .ui files")

# Determine platform
if os.name == "nt":  # Windows
    pyuic_exec_file = "pyuic5.exe"
elif os.name == "posix":  # Linux
    pyuic_exec_file = "pyuic5"
else:
    raise ValueError("Unknown OS name [" + os.name + "]")

# Build the path to the `pyuic` executable
pyuic_exec_path = os.path.join(base_path, "venv/bin", pyuic_exec_file)
if not os.path.exists(pyuic_exec_path):
    raise FileNotFoundError(
        "[" + pyuic_exec_path + "] not found. Please install PyQt5."
    )

# Find destination folder for .py output files
possible_pkg_names = [os.path.basename(os.path.abspath(os.path.pardir)), "src"]
dest_dir = None
for possible_pkg_name in possible_pkg_names:
    possible_pkg_name = os.path.join(base_path, possible_pkg_name)
    if os.path.exists(possible_pkg_name):
        dest_dir = os.path.join(possible_pkg_name, "gui")
        if not os.path.exists(dest_dir):
            os.mkdir(dest_dir)
if dest_dir is None:
    raise FileNotFoundError("No destination directory found.")

# Convert all .ui files into .py files
for ui_file in os.listdir(pyqt_dir):
    if ui_file.endswith(".ui"):
        ui_file_basename = os.path.splitext(ui_file)[0]
        py_file = os.path.join(dest_dir, "ui_" + ui_file_basename + ".py")
        os.system(
            pyuic_exec_path + " " + os.path.join(pyqt_dir, ui_file) + " -o " + py_file
        )
        if ui_file.endswith("_dialog.ui"):
            create_window_file(ui_file_basename, dest_dir)
