from configobj import ConfigObj
import utils
import threading
import os


class Config:
    def __init__(self, filename):
        if os.path.exists("../config/" + filename):
            self.full_filename = "../config/" + filename
        elif os.path.exists("./" + filename):
            self.full_filename = "./" + filename
        else:
            raise FileNotFoundError(
                "Could not find " + os.path.abspath("./" + filename)
            )
        self.config_parser = ConfigObj(self.full_filename, encoding="utf8")
        self.file_access_lock = threading.Lock()

    def write(self, instrument, key, value):
        self.file_access_lock.acquire()

        self.config_parser.reload()
        self.config_parser[instrument][key] = str(value)
        self.config_parser.write()
        self.file_access_lock.release()

    def read(self, instrument, key):
        self.file_access_lock.acquire()
        self.config_parser.reload()
        try:
            value = self.config_parser[instrument][key]
        except:
            self.file_access_lock.release()
            raise
        self.file_access_lock.release()
        value = utils.convert_to_numeric(value)
        return value
